# Wraping for the CIFAR dataset

from typing import Callable, Optional

from torchvision.datasets import FGVCAircraft as FGVCAircraft_tv
from torchvision.transforms import transforms


class FGVCAircraft(FGVCAircraft_tv):

    def __init__(
        self,
        root: str,
        train: bool = True,
        transform: Optional[Callable] = None,
        target_transform: Optional[Callable] = None,
        download: bool = False,
    ) -> None:

        super().__init__(root,
                         split="train" if train else "test",
                         transform=transforms.ToTensor()
                         if transform is None else transform,
                         target_transform=target_transform,
                         download=download)

        self.classes_names = self.classes
        self.targets = self._labels

        self.mean, self.std = (0.485, 0.456, 0.406), (0.229, 0.224, 0.225)
        if isinstance(self.transform, transforms.Compose):
            self.transform.transforms.append(
                transforms.Normalize(self.mean, self.std))


if __name__ == "__main__":
    dataset = FGVCAircraft(root="data", train=True, download=True)
    print(len(dataset), len(dataset.classes_names))
